summaryrefslogtreecommitdiffstats
path: root/qtsharp/src/bindings/static/QToolButton.cs
diff options
context:
space:
mode:
Diffstat (limited to 'qtsharp/src/bindings/static/QToolButton.cs')
-rw-r--r--qtsharp/src/bindings/static/QToolButton.cs46
1 files changed, 23 insertions, 23 deletions
diff --git a/qtsharp/src/bindings/static/QToolButton.cs b/qtsharp/src/bindings/static/QToolButton.cs
index 90f36785..1ccc243f 100644
--- a/qtsharp/src/bindings/static/QToolButton.cs
+++ b/qtsharp/src/bindings/static/QToolButton.cs
@@ -1,4 +1,4 @@
// QToolButton.cs - A Qt to C# binding.
//
// Copyright (C) 2002 Adam Treat (manyoso@yahoo.com)
//
@@ -26,11 +26,11 @@ namespace Qt {
using System;
using System.Runtime.InteropServices;
- public class QToolButton : QButton, IDisposable {
+ public class TQToolButton : TQButton, IDisposable {
[DllImport("libqtc", CharSet=CharSet.Ansi)]
private static extern IntPtr qt_new_QToolButton (IntPtr parent, string name);
- public QToolButton (QWidget parent, string name) : this (QNull.Instance)
+ public TQToolButton (TQWidget parent, string name) : this (QNull.Instance)
{
rawObject = qt_new_QToolButton (parent != null ? parent.RawObject : IntPtr.Zero, name);
@@ -38,27 +38,27 @@ namespace Qt {
qparent.AddChild (this);
RegisterObject (this);
- Connect (this, SIGNAL ("destroyed ()"), SLOT ("NativeDestroyed ()"));
+ Connect (this, TQT_SIGNAL ("destroyed ()"), TQT_SLOT ("NativeDestroyed ()"));
}
[DllImport("libqtc", CharSet=CharSet.Ansi)]
private static extern IntPtr qt_new_QToolButton1 (IntPtr iconSet, IntPtr textLabel, IntPtr groupText, IntPtr receiver, string slot, IntPtr parent, string name);
- public QToolButton (QIconSet iconSet, QString textLabel, QString groupText, QObject receiver, string slot, QToolBar parent, string name) : this (QNull.Instance)
+ public TQToolButton (TQIconSet iconSet, TQString textLabel, TQString groupText, TQObject receiver, string slot, TQToolBar parent, string name) : this (QNull.Instance)
{
rawObject = qt_new_QToolButton1 (iconSet.RawObject, textLabel.RawObject, groupText.RawObject, IntPtr.Zero, null, parent != null ? parent.RawObject : IntPtr.Zero, name);
- Connect( this, SIGNAL("clicked()"), receiver, slot );
+ Connect( this, TQT_SIGNAL("clicked()"), receiver, slot );
if ((qparent = parent) != null)
qparent.AddChild (this);
RegisterObject (this);
- Connect (this, SIGNAL ("destroyed ()"), SLOT ("NativeDestroyed ()"));
+ Connect (this, TQT_SIGNAL ("destroyed ()"), TQT_SLOT ("NativeDestroyed ()"));
}
[DllImport("libqtc", CharSet=CharSet.Ansi)]
private static extern IntPtr qt_new_QToolButton2 (Qt.ArrowType type, IntPtr parent, string name);
- public QToolButton (Qt.ArrowType type, QWidget parent, string name) : this (QNull.Instance)
+ public TQToolButton (Qt.ArrowType type, TQWidget parent, string name) : this (QNull.Instance)
{
rawObject = qt_new_QToolButton2 (type, parent != null ? parent.RawObject : IntPtr.Zero, name);
@@ -66,22 +66,22 @@ namespace Qt {
qparent.AddChild (this);
RegisterObject (this);
- Connect (this, SIGNAL ("destroyed ()"), SLOT ("NativeDestroyed ()"));
+ Connect (this, TQT_SIGNAL ("destroyed ()"), TQT_SLOT ("NativeDestroyed ()"));
}
- public QToolButton (QWidget parent) : this (parent, "") {}
+ public TQToolButton (TQWidget parent) : this (parent, "") {}
- internal QToolButton () : this (QNull.Instance) {}
+ internal TQToolButton () : this (QNull.Instance) {}
- internal QToolButton (IntPtr ptr) : this (QNull.Instance)
+ internal TQToolButton (IntPtr ptr) : this (QNull.Instance)
{
rawObject = ptr;
RegisterObject(this);
}
- internal QToolButton (QNull dummy) : base (QNull.Instance) {}
+ internal TQToolButton (QNull dummy) : base (QNull.Instance) {}
- ~QToolButton ()
+ ~TQToolButton ()
{
Dispose (false);
}
@@ -116,7 +116,7 @@ namespace Qt {
[DllImport("libqtc", CharSet=CharSet.Ansi)]
private static extern void qt_QToolButton_setTextLabel (IntPtr raw, IntPtr arg1, bool arg2);
- public void SetTextLabel (QString arg1, bool arg2)
+ public void SetTextLabel (TQString arg1, bool arg2)
{
if (disposed)
throw new ObjectDisposedException (this+": Attempted use of disposed object");
@@ -156,7 +156,7 @@ namespace Qt {
[DllImport("libqtc", CharSet=CharSet.Ansi)]
private static extern void qt_QToolButton_setTextLabel1 (IntPtr raw, IntPtr arg1);
- public void SetTextLabel (QString arg1)
+ public void SetTextLabel (TQString arg1)
{
if (disposed)
throw new ObjectDisposedException (this+": Attempted use of disposed object");
@@ -166,7 +166,7 @@ namespace Qt {
[DllImport("libqtc", CharSet=CharSet.Ansi)]
private static extern void qt_QToolButton_setIconSet (IntPtr raw, IntPtr set);
- public void SetIconSet (QIconSet set)
+ public void SetIconSet (TQIconSet set)
{
if (disposed)
throw new ObjectDisposedException (this+": Attempted use of disposed object");
@@ -176,7 +176,7 @@ namespace Qt {
[DllImport("libqtc", CharSet=CharSet.Ansi)]
private static extern void qt_QToolButton_setIconSet1 (IntPtr raw, IntPtr set, bool on);
- public void SetIconSet (QIconSet set, bool on)
+ public void SetIconSet (TQIconSet set, bool on)
{
if (disposed)
throw new ObjectDisposedException (this+": Attempted use of disposed object");
@@ -186,12 +186,12 @@ namespace Qt {
[DllImport("libqtc", CharSet=CharSet.Ansi)]
private static extern IntPtr qt_QToolButton_iconSet (IntPtr raw, bool on);
- public QIconSet IconSet (bool on)
+ public TQIconSet IconSet (bool on)
{
if (disposed)
throw new ObjectDisposedException (this+": Attempted use of disposed object");
- return LookupObject (qt_QToolButton_iconSet (rawObject, on), typeof (QIconSet)) as QIconSet;
+ return LookupObject (qt_QToolButton_iconSet (rawObject, on), typeof (TQIconSet)) as QIconSet;
}
[DllImport("libqtc", CharSet=CharSet.Ansi)]
@@ -246,7 +246,7 @@ namespace Qt {
[DllImport("libqtc", CharSet=CharSet.Ansi)]
private static extern void qt_QToolButton_drawButtonLabel (IntPtr raw, IntPtr arg1);
- protected void DrawButtonLabel (QPainter arg1)
+ protected void DrawButtonLabel (TQPainter arg1)
{
if (disposed)
throw new ObjectDisposedException (this+": Attempted use of disposed object");
@@ -266,7 +266,7 @@ namespace Qt {
[DllImport("libqtc", CharSet=CharSet.Ansi)]
private static extern bool qt_QToolButton_eventFilter (IntPtr raw, IntPtr o, IntPtr e);
- protected bool EventFilter (QObject o, QEvent e)
+ protected bool EventFilter (TQObject o, TQEvent e)
{
if (disposed)
throw new ObjectDisposedException (this+": Attempted use of disposed object");
@@ -276,7 +276,7 @@ namespace Qt {
[DllImport("libqtc", CharSet=CharSet.Ansi)]
private static extern void qt_QToolButton_paletteChange (IntPtr raw, IntPtr arg1);
- protected void PaletteChange (QPalette arg1)
+ protected void PaletteChange (TQPalette arg1)
{
if (disposed)
throw new ObjectDisposedException (this+": Attempted use of disposed object");
@@ -1,4 +1,4 @@
-// QToolButton.cs - A Qt to C# binding.
+// TQToolButton.cs - A Qt to C# binding.
//
// Copyright (C) 2002 Adam Treat (manyoso@yahoo.com)